==> nm-tray_0.4.2.orig.tar.gz: nm-tray-0.4.2/translations/nm-tray_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>ConnectionInfo</name>
    <message>
        <location filename="../src/connectioninfo.ui" line="14"/>
        <source>Connection information</source>
        <translation>Ryšio informacija</translation>
    </message>
</context>
<context>
    <name>NmList</name>
    <message>
        <location filename="../src/nmlist.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogas</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="20"/>
        <source>All information</source>
        <translation>Visa informacija</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="30"/>
        <source>Active connections</source>
        <translation>Aktyvūs ryšiai</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="40"/>
        <source>Available wireless</source>
        <translation>Prieinami belaidžiai</translation>
    </message>
</context>
<context>
    <name>NmModel</name>
    <message>
        <location filename="../src/nmmodel.cpp" line="55"/>
        <source>nm-tray - wireless password</source>
        <translation>nm-tray - belaidžio slaptažodis</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="56"/>
        <source>Password is needed for connection to &apos;%1&apos;:</source>
        <translation>Norint prisijungti prie &quot;%1&quot;, reikalingas slaptažodis:</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="744"/>
        <source>root</source>
        <translation>šaknis</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="746"/>
        <source>active connection(s)</source>
        <translation>aktyvus ryšys(-iai)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="748"/>
        <source>connection(s)</source>
        <translation>ryšys(-iai)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="750"/>
        <source>device(s)</source>
        <translation>įrenginys(-iai)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="752"/>
        <source>wifi network(s)</source>
        <translation>belaidis tinklas(-ai)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1043"/>
        <source>unknown</source>
        <comment>hardware address</comment>
        <translation>nežinoma</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1151"/>
        <source>General</source>
        <comment>Active connection information</comment>
        <translation>Bendra</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1152"/>
        <source>Interface</source>
        <comment>Active connection information</comment>
        <translation>Sąsaja</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1154"/>
        <source>Hardware Address</source>
        <comment>Active connection information</comment>
        <translation>Aparatinės įrangos adresas</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1156"/>
        <source>Driver</source>
        <comment>Active connection information</comment>
        <translation>Tvarkyklė</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1158"/>
        <source>Speed</source>
        <comment>Active connection information</comment>
        <translation>Greitis</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1160"/>
        <source> Kb/s</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1162"/>
        <source>unknown</source>
        <comment>Speed</comment>
        <translation>nežinoma</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1166"/>
        <source>Security</source>
        <comment>Active connection information</comment>
        <translation>Saugumas</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1170"/>
        <source>IPv4</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1171"/>
        <source>IPv6</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1182"/>
        <source>IP Address</source>
        <comment>Active connection information</comment>
        <translation>IP adresas</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1184"/>
        <source>Subnet Mask</source>
        <comment>Active connection information</comment>
        <translation>Potinklio kaukė</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1193"/>
        <source>Default route</source>
        <comment>Active connection information</comment>
        <translation>Numatytasis maršrutas</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1199"/>
        <source>DNS(%1)</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tray</name>
    <message>
        <location filename="../src/tray.cpp" line="123"/>
        <source>&lt;pre&gt;Connection &lt;strong&gt;%1&lt;/strong&gt;(%2) active&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Ryšys &lt;strong&gt;%1&lt;/strong&gt;(%2) aktyvus&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="129"/>
        <source>&lt;pre&gt;No active connection&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Nėra aktyvių ryšių&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="202"/>
        <source>Connection lost</source>
        <translation>Ryšys nutrūko</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="203"/>
        <source>No longer connected to %1 &apos;%2&apos;.</source>
        <translation>Daugiau nebeprisijungta prie %1 &quot;%2&quot;.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="215"/>
        <source>Connection established</source>
        <translation>Ryšys užmegztas</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="216"/>
        <source>Now connected to %1 &apos;%2&apos;.</source>
        <translation>Dabar prisijungta prie %1 &quot;%2&quot;.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="220"/>
        <source>NetworkManager(nm-tray)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="253"/>
        <source>Enable Networking</source>
        <translation>Įjungti darbą tinkle</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="254"/>
        <source>Enable Wi-Fi</source>
        <translation>Įjungti belaidį</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="256"/>
        <source>Enable notifications</source>
        <translation>Įjungti pranešimus</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="258"/>
        <source>Connection information</source>
        <translation>Ryšio informacija</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="259"/>
        <source>Debug information</source>
        <translation>Derinimo informacija</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="260"/>
        <source>Wifi - request scan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="261"/>
        <source>Edit connections...</source>
        <translation>Taisyti ryšius...</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="264"/>
        <source>About</source>
        <translation>Apie</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="266"/>
        <source>Quit</source>
        <translation>Išeiti</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="291"/>
        <source>nm-tray info</source>
        <translation>nm-tray informacija</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="384"/>
        <source>%1 about</source>
        <translation>Apie %1</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="385"/>
        <source>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; is a simple Qt based frontend for &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version: %1</source>
        <translation>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; yra paprasta Qt pagrįsta naudotojo sąsaja, kuri skirta &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Versija: %1</translation>
    </message>
</context>
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/windowmenu.cpp" line="163"/>
        <source>Active connection(s)</source>
        <translation>Aktyvus ryšys(-iai)</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="165"/>
        <source>Wi-Fi network(s)</source>
        <translation>Belaidis tinklas(-ai)</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="167"/>
        <source>Known connection(s)</source>
        <translation>Žinomas ryšys(-iai)</translation>
    </message>
</context>
</TS>

==> nm-tray_0.4.3.orig.tar.gz: nm-tray-0.4.3/translations/nm-tray_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>ConnectionInfo</name>
    <message>
        <location filename="../src/connectioninfo.ui" line="14"/>
        <source>Connection information</source>
        <translation>Ryšio informacija</translation>
    </message>
</context>
<context>
    <name>NmList</name>
    <message>
        <source>Dialog</source>
        <translation type="vanished">Dialogas</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="17"/>
        <source>All information</source>
        <translation>Visa informacija</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="27"/>
        <source>Active connections</source>
        <translation>Aktyvūs ryšiai</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="37"/>
        <source>Available wireless</source>
        <translation>Prieinami belaidžiai</translation>
    </message>
</context>
<context>
    <name>NmModel</name>
    <message>
        <location filename="../src/nmmodel.cpp" line="55"/>
        <source>nm-tray - wireless password</source>
        <translation>nm-tray - belaidžio slaptažodis</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="56"/>
        <source>Password is needed for connection to &apos;%1&apos;:</source>
        <translation>Norint prisijungti prie &quot;%1&quot;, reikalingas slaptažodis:</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="744"/>
        <source>root</source>
        <translation>šaknis</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="746"/>
        <source>active connection(s)</source>
        <translation>aktyvus ryšys(-iai)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="748"/>
        <source>connection(s)</source>
        <translation>ryšys(-iai)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="750"/>
        <source>device(s)</source>
        <translation>įrenginys(-iai)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="752"/>
        <source>wifi network(s)</source>
        <translation>belaidis tinklas(-ai)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1043"/>
        <source>unknown</source>
        <comment>hardware address</comment>
        <translation>nežinoma</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1151"/>
        <source>General</source>
        <comment>Active connection information</comment>
        <translation>Bendra</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1152"/>
        <source>Interface</source>
        <comment>Active connection information</comment>
        <translation>Sąsaja</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1154"/>
        <source>Hardware Address</source>
        <comment>Active connection information</comment>
        <translation>Aparatinės įrangos adresas</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1156"/>
        <source>Driver</source>
        <comment>Active connection information</comment>
        <translation>Tvarkyklė</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1158"/>
        <source>Speed</source>
        <comment>Active connection information</comment>
        <translation>Greitis</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1160"/>
        <source> Kb/s</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1162"/>
        <source>unknown</source>
        <comment>Speed</comment>
        <translation>nežinoma</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1166"/>
        <source>Security</source>
        <comment>Active connection information</comment>
        <translation>Saugumas</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1170"/>
        <source>IPv4</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1171"/>
        <source>IPv6</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1182"/>
        <source>IP Address</source>
        <comment>Active connection information</comment>
        <translation>IP adresas</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1184"/>
        <source>Subnet Mask</source>
        <comment>Active connection information</comment>
        <translation>Potinklio kaukė</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1193"/>
        <source>Default route</source>
        <comment>Active connection information</comment>
        <translation>Numatytasis maršrutas</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1199"/>
        <source>DNS(%1)</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tray</name>
    <message>
        <location filename="../src/tray.cpp" line="123"/>
        <source>&lt;pre&gt;Connection &lt;strong&gt;%1&lt;/strong&gt;(%2) active&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Ryšys &lt;strong&gt;%1&lt;/strong&gt;(%2) aktyvus&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="129"/>
        <source>&lt;pre&gt;No active connection&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Nėra aktyvių ryšių&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="202"/>
        <source>Connection lost</source>
        <translation>Ryšys nutrūko</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="203"/>
        <source>No longer connected to %1 &apos;%2&apos;.</source>
        <translation>Daugiau nebeprisijungta prie %1 &quot;%2&quot;.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="215"/>
        <source>Connection established</source>
        <translation>Ryšys užmegztas</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="216"/>
        <source>Now connected to %1 &apos;%2&apos;.</source>
        <translation>Dabar prisijungta prie %1 &quot;%2&quot;.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="220"/>
        <source>NetworkManager(nm-tray)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="253"/>
        <source>Enable Networking</source>
        <translation>Įjungti darbą tinkle</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="254"/>
        <source>Enable Wi-Fi</source>
        <translation>Įjungti belaidį</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="256"/>
        <source>Enable notifications</source>
        <translation>Įjungti pranešimus</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="258"/>
        <source>Connection information</source>
        <translation>Ryšio informacija</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="259"/>
        <source>Debug information</source>
        <translation>Derinimo informacija</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="260"/>
        <source>Wifi - request scan</source>
        <translation>Belaidis - skenuoti tinklus</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="261"/>
        <source>Edit connections...</source>
        <translation>Taisyti ryšius...</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="264"/>
        <source>About</source>
        <translation>Apie</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="266"/>
        <source>Quit</source>
        <translation>Išeiti</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="291"/>
        <source>nm-tray info</source>
        <translation>nm-tray informacija</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="384"/>
        <source>%1 about</source>
        <translation>Apie %1</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="385"/>
        <source>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; is a simple Qt based frontend for &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version: %1</source>
        <translation>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; yra paprasta Qt pagrįsta naudotojo sąsaja, kuri skirta &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Versija: %1</translation>
    </message>
</context>
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/windowmenu.cpp" line="163"/>
        <source>Active connection(s)</source>
        <translation>Aktyvus ryšys(-iai)</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="165"/>
        <source>Wi-Fi network(s)</source>
        <translation>Belaidis tinklas(-ai)</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="167"/>
        <source>Known connection(s)</source>
        <translation>Žinomas ryšys(-iai)</translation>
    </message>
</context>
</TS>
